# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_llm_config_model_endpoint_item import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
)

AgentsSearchResponseAgentsItemLlmConfigModelEndpoint = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem]],
    typing.Optional[typing.Any],
]
