# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_embedding_config_embedding_chunk_size_item import (
    TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
)

TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSize = typing.Union[
    float,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem]],
    typing.Optional[typing.Any],
]
