# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .web_search_options_search_context_size import WebSearchOptionsSearchContextSize
from .web_search_options_user_location import WebSearchOptionsUserLocation
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class WebSearchOptions(UncheckedBaseModel):
    search_context_size: typing.Optional[WebSearchOptionsSearchContextSize] = None
    user_location: typing.Optional[WebSearchOptionsUserLocation] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
